## Load Arabidopsis data
data(arab);
## Specify treatment groups
grp.ids = c(1, 1, 1, 2, 2, 2);
## Prepare an NBP object, adjust the library sizes by thinning the counts.
set.seed(999);
## For demonstration purpose, we will use the first 100 rows of the data
obj = prepare.nbp(arab[1:100,], grp.ids, print.level=5);
## Estimate the NBP dispersion parameters
obj = estimate.disp(obj, print.level=5);
## Print the NBP object
print.nbp(obj);Run the code above in your browser using DataLab