estimate.norm.factors estiamtes normalization
factors to account for apparent reduction or increase in
relative frequencies of non-differentially expressing
genes as a result of compensating the increased or
decreased relative frequencies of truly differentially
expressing genes.estimate.norm.factors(counts, lib.sizes, method)The concern introduced in Robinson and Oshlack (2010) is that this reduction will give a false impression of biological relevance. Since the accommodation for relative frequencies summing to one is shared equally by a very large number of non-differentially expressing genes, we suspect that the effect is usually small, but examples where it is non-ignorable have been demonstrated (Robinson and Oshlack, 2010).
A simple fix is to compute the relative frequencies relative to effective library sizes---library sizes multiplied by normalization factors.
Robinson, M. D. and A. Oshlack (2010): "A scaling normalization method for differential expression analysis of RNA-seq data," Genome Biol., 11, R25.}